CropImageView class
crop image view
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CropImageView
Constructors
- CropImageView({Key? key, required CropImageViewController controller, double minWidth = 50, double minHeight = 50, Color borderColor = Colors.white70, Color threeLineColor = Colors.white70, Color cornerColor = Colors.white70, double? ratio, double initScale = 0.9, Color scrimColor = Colors.black54, bool cornerShow = true, double cornerLength = 15, double cornerWidth = 3, double borderWidth = 1, bool borderShow = true, double threeLineWidth = 1, bool threeLineShow = true, Widget? loading})
-
const
Properties
- borderColor → Color
-
border color
final
- borderShow → bool
-
border show
final
- borderWidth → double
-
border width
final
- controller → CropImageViewController
-
controller
final
- cornerColor → Color
-
corner color
final
- cornerLength → double
-
corner length
final
- cornerShow → bool
-
corner show
final
- cornerWidth → double
-
corner width
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initScale → double
-
init scale
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loading → Widget?
-
loading widget
final
- minHeight → double
-
min height
final
- minWidth → double
-
min width
final
- ratio → double?
-
ratio
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrimColor → Color
-
scrimColor
final
- threeLineColor → Color
-
three line color
final
- threeLineShow → bool
-
three line show
final
- threeLineWidth → double
-
three line width
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited